@@ -6,7 +6,7 @@ import warnings
 import numpy as np
 from scipy import fft, signal
 from IPython.display import display
-from miniaudio import get_file_info, decode_file, SampleFormat, DecodeError
+from miniaudio import get_file_info, decode_file, SampleFormat, FileFormat, DecodeError
 from bokeh.plotting import figure, show
 from bokeh.layouts import gridplot
 from bokeh.models import ColumnDataSource
@@ -232,16 +232,19 @@ class AudioSignal(TimeSignal):
     """
     def __init__(self, in_data, samplerate=None):
         if isinstance(in_data, (str, Path)):
+            file_path = str(in_data)
             try:
                 if samplerate is None:
-                    file_info = get_file_info(in_data)
+                    file_info = get_file_info(file_path)
                     samplerate = file_info.sample_rate
-                decoded_file = decode_file(filename=in_data, output_format=SampleFormat.FLOAT32,
+                decoded_file = decode_file(filename=file_path, output_format=SampleFormat.FLOAT32,
                                            nchannels=1, sample_rate=samplerate)
+                if decoded_file.file_format == FileFormat.UNKNOWN:
+                    raise DecodeError('Unknown file format')
                 samples = np.asarray(decoded_file.samples)
             except DecodeError as decode_error:
                 try:
-                    samples, file_samplerate = _read_aiff_file(in_data, mix_to_mono=True)
+                    samples, file_samplerate = _read_aiff_file(file_path, mix_to_mono=True)
                     if samplerate is None:
                         samplerate = file_samplerate
                     elif samplerate != file_samplerate:
